@@ -8,6 +8,7 @@ import java.util.List;
 
 import org.gcube.portlets.user.gisviewer.client.commons.beans.DataResult;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.GeoserverItem;
+import org.gcube.portlets.user.gisviewer.client.commons.beans.GisViewerBaseLayerInterface;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItem;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItemsResult;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.MapViewInfo;
@@ -44,6 +45,14 @@ import com.google.gwt.user.client.ui.Image;
 public class GisViewerPanel extends LayoutContainer 
 implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandler, OpenLayersHandler {
 
+	/**
+	 * 
+	 */
+
+	/**
+	 * 
+	 */
+
 	private static final String ALERT_HARD_SPATIAL_QUERY = "The spatial query can take long time. Do you want to continue to download it?";
 	private GisViewerLayout mainPanel;
 	private LayersPanel layersPanel;
@@ -365,8 +374,13 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 				urls.add(geoserverItem.getUrl() + urlRequest);						
 			}
 		} else if (clickDataInfo.isBox()) {
-			for (LayerItem layerItem : visibleLayerItems)
-				urls.add(URLMakers.getWfsFeatureUrl(layerItem, clickDataInfo.getBbox(), 0, "csv"));
+			for (LayerItem layerItem : visibleLayerItems){
+				
+				//ADDED BY FRANCESCO M.
+				int limit = clickDataInfo.getLimit()==Integer.MAX_VALUE?0:1;
+
+				urls.add(URLMakers.getWfsFeatureUrl(layerItem, clickDataInfo.getBbox(), limit, Constants.CSV));
+			}
 		}
 			
 		return urls;
@@ -380,8 +394,7 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 			List<String> urls = gerUrlsForClickData(lastClickDataInfo);
 			mainPanel.setDataPanelWait(true);
 
-			gisViewerServiceAsync.getDataResult(urls,
-					new AsyncCallback<List<DataResult>>() {
+			gisViewerServiceAsync.getDataResult(urls,new AsyncCallback<List<DataResult>>() {
 				@Override
 				public void onSuccess(List<DataResult> result) {
 					DataResultPanel dpanel = new DataResultPanel();
@@ -399,7 +412,10 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 			String bbox = lastClickDataInfo.getBbox();
 			mainPanel.setDataPanelWait(true);
 
-			gisViewerServiceAsync.getDataResult(layersPanel.getVisibleLayers(), bbox, new AsyncCallback<List<WfsTable>>() {
+			int maxWFSFeature = lastClickDataInfo.getLimit()==Integer.MAX_VALUE?Constants.MAX_WFS_FEATURES:lastClickDataInfo.getLimit();
+			GWT.log("Max WFS Feature is "+maxWFSFeature);
+			
+			gisViewerServiceAsync.getDataResult(layersPanel.getVisibleLayers(), bbox, maxWFSFeature, new AsyncCallback<List<WfsTable>>() {
 				@Override
 				public void onSuccess(List<WfsTable> result) {
 					DataResultPanel dpanel = new DataResultPanel();
@@ -614,16 +630,32 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 		}
 	}
 
-	private String getLayerImageUrl(LayerItem layerItem, String format,
-			boolean isWMS) {
-		String url;
+	private String getLayerImageUrl(LayerItem layerItem, String format, boolean isWMS) {
+		String url ="";
 		if (isWMS) {
 			String cqlFilter = layerItem.getCqlFilter();
 			MapViewInfo mapViewInfo = openLayersMap.getMapViewInfo();
-			url = "/wms?SERVICE=WMS&version=1.1.0&REQUEST=GetMap&LAYERS="
+
+			//COMMENTED 26/08/2014
+//			url = "/wms?SERVICE=WMS&version=1.1.0&REQUEST=GetMap&LAYERS="
+
+			if(layerItem.getGeoserverUrl().contains(Constants.WXS)){
+				GWT.log("is mapserver, skipping add "+Constants.WMS);
+				System.out.println("is mapserver, skipping add "+Constants.WMS);
+			}else{
+				System.out.println("is geoserver adding "+Constants.WMS);
+				GWT.log("is geoserver adding "+Constants.WMS);
+				url+=Constants.WMS;
+			}
+			
+			String styles="";
+			if(layerItem.getStyle()!=null && !layerItem.getStyle().isEmpty()){
+				styles = "&STYLES="+layerItem.getStyle();
+			}
+
+			url += 	"?SERVICE=WMS&version=1.1.0&REQUEST=GetMap&LAYERS="
 					+ layerItem.getLayer()
-					+ "&STYLES="
-					+ layerItem.getStyle()
+					+ styles
 					+ "&BBOX=" + mapViewInfo.getLowerLeftX()
 					+ "," + mapViewInfo.getLowerLeftY()
 					+ "," + mapViewInfo.getUpperRightX()
@@ -638,7 +670,11 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 			url = "/ows?service=WFS&version=1.0.0&request=GetFeature&typeName="
 					+ layerItem.getLayer() + "&outputFormat=" + format;
 		}
-		return layerItem.getGeoserverUrl()+url;
+		
+		String fullImageUrl = layerItem.getGeoserverUrl()+url;
+//		System.out.println("returning wms image request: "+fullImageUrl);
+//		Window.alert(fullImageUrl);
+		return fullImageUrl;
 	}
 
 	@Override
@@ -789,6 +825,9 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 			// create a new click data information
 			lastClickDataInfo = new ClickDataInfo(x1, y1, x2, y2);
 
+			if(toolBarPanel.isPointDataTogglePressed())
+				lastClickDataInfo.setLimit(1);
+			
 			// create a list of url request for data (for each geoserver)
 			showDataPanel();
 		}
@@ -796,7 +835,7 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 	
 	/**
 	 * 
-	 * Addeb by Francesco
+	 * by Francesco M.
 	 * Extension of addLayerByWms, with input parameter is external layer
 	 * @param title
 	 * @param layerName
@@ -819,7 +858,7 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 		l.setExternal(isExternal);
 		l.setOpacity(1d);
 		l.setBuffer(2);
-
+		
 		switch (layerType) {
 		
 		//TODO IMPLEMENT THIS CASE
@@ -860,7 +899,7 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 	
 
 	/**
-	 * Addeb by Francesco
+	 * by Francesco M.
 	 * 
 	 * @param layerType
 	 * @param listLayerItem
@@ -899,5 +938,16 @@ implements ToolbarHandler, DataPanelHandler, LayersPanelHandler, CqlFilterHandle
 		layersPanel.addLayerItems(listLayerItem, onTop);
 		layersPanel.updateLayersOrder();
 	}
+	
+	/**
+	 * by Francesco M.
+	 * 
+	 * @param layerType
+	 * @param listLayerItem
+	 * @param onTop
+	 */
+	public void addBaseLayersToOLM(List<? extends GisViewerBaseLayerInterface> layers){
+		openLayersMap.addBaseLayersToOpenLayerMap((List<GisViewerBaseLayerInterface>) layers);
+	}
 
 }
