@@ -5,6 +5,7 @@ import java.util.HashMap;
 import java.util.List;
 
 import org.gcube.portlets.user.gisviewer.client.Constants;
+import org.gcube.portlets.user.gisviewer.client.commons.beans.GisViewerBaseLayerInterface;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItem;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.MapViewInfo;
 import org.gwtopenmaps.openlayers.client.Bounds;
@@ -78,6 +79,7 @@ public class OpenLayersMap {
 	private OpenLayersHandler handler=null;
 	private int maxZindex = 0;
 	private ToolBarPanel toolBarPanel;
+	private List<GisViewerBaseLayerInterface> baseLayersIntefaces;
 	
 	// constructor
 	public OpenLayersMap(String w, String h, int numZoomLevels, // projection, transectUrl removed
@@ -151,8 +153,10 @@ public class OpenLayersMap {
 		map.addLayer(vectorLayer);
 		vectorLayer.setZIndex(MAX_ZINDEX);
 		
-		addBaseLayers();
+//		addBaseLayers();
 
+		addBaseLayerToOpenLayerMap(Constants.TRUE_MARBLE_TITLE, Constants.TRUE_MARBLE_NAME, Constants.TRUE_MARBLE_URL);
+		
 		addControl(mouseDefaults);
 		addControl(pamZoomBar);
 		addControl(getMousePosition());
@@ -509,8 +513,7 @@ public class OpenLayersMap {
 
 	public void setNewStyle(LayerItem layerItem, String newStyle) {
 		Layer layer = mappingLayerItemsToLayers.get(layerItem);
-		layer.getJSObject().getProperty("params")
-				.setProperty("STYLES", newStyle);
+		layer.getJSObject().getProperty("params").setProperty("STYLES", newStyle);
 		layer.redraw();
 	}
 
@@ -615,10 +618,29 @@ public class OpenLayersMap {
 		mappingLayersToLayerItems.remove(layer);
 	}
 
+	
+	public void resetBaseLayerToOpenLayerMap(){
+		baseLayersIntefaces.clear();
+	}
+	
+	
 	/**
 	 * 
 	 */
-	private void addBaseLayers() {
+	public void addBaseLayersToOpenLayerMap(List<GisViewerBaseLayerInterface> layers) {
+
+		if(baseLayersIntefaces==null){
+			baseLayersIntefaces = new ArrayList<GisViewerBaseLayerInterface>();
+		}
+		
+		baseLayersIntefaces.addAll(layers);
+		
+		for (GisViewerBaseLayerInterface baseLayerInterface : layers) {
+			if(baseLayerInterface.isDisplay())
+				addBaseLayerToOpenLayerMap(baseLayerInterface.getTitle(), baseLayerInterface.getName(), baseLayerInterface.getWmsURL());
+		}
+		
+		
 //		options = new GoogleV3Options();
 //		options.setIsBaseLayer(true);
 //		options.setDisplayInLayerSwitcher(true);
@@ -635,18 +657,18 @@ public class OpenLayersMap {
 //		mapOptions.setMaxResolutionToAuto();
 //		mapWidget.getMap().setOptions(mapOptions);
 
-		addBaseLayer("True Marble", "truemarble", "http://romeo.jrc.it/maps/mapserv.cgi?map=../mapfiles/acpmap_static.map&");
+		
 //		addBaseLayer("Blue Marble", "bluemarble_1", "http://iceds.ge.ucl.ac.uk/cgi-bin/icedswms");
-		addBaseLayer("Global Surface Relief", "etopo1_ice:z", "http://oos.soest.hawaii.edu/erddap/wms/etopo1_ice/request");
-		addBaseLayer("Shaded Relief", "shaded_relief", "http://maps.ngdc.noaa.gov/soap/etopo1/MapServer/WMSServer");
-		addBaseLayer("Dem", "dem", "http://maps.ngdc.noaa.gov/soap/etopo1/MapServer/WMSServer");
-		addBaseLayer("Etopo180", "etopo180:altitude", "http://coastwatch.pfeg.noaa.gov/erddap/wms/erdBAssta5day/request");
-		addBaseLayer("Groundwater Map", "bgr_groundwater_whymap", "http://www.bgr.de/Service/groundwater/whymap/");
-		addBaseLayer("LandMask", "LandMask", "http://oos.soest.hawaii.edu/erddap/wms/etopo1_ice/request");
-		addBaseLayer("Coastlines", "Coastlines", "http://oos.soest.hawaii.edu/erddap/wms/etopo1_ice/request");
-//		addBaseLayer("test2", "NWW3_Global_Best:Tdir", "http://oos.soest.hawaii.edu/erddap/wms/NWW3_Global_Best/request");
-		addBaseLayer("GEBCO", "GEBCO_08_Grid", "http://www.gebco.net/data_and_products/web_map_service/mapserv/request");
-		addBaseLayer("test2", "", ""); // do not anything
+//		addBaseLayerToOpenLayerMap("Global Surface Relief", "etopo1_ice:z", "http://oos.soest.hawaii.edu/erddap/wms/etopo1_ice/request");
+//		addBaseLayerToOpenLayerMap("Shaded Relief", "shaded_relief", "http://maps.ngdc.noaa.gov/soap/etopo1/MapServer/WMSServer");
+//		addBaseLayerToOpenLayerMap("Dem", "dem", "http://maps.ngdc.noaa.gov/soap/etopo1/MapServer/WMSServer");
+//		addBaseLayerToOpenLayerMap("Etopo180", "etopo180:altitude", "http://coastwatch.pfeg.noaa.gov/erddap/wms/erdBAssta5day/request");
+//		addBaseLayerToOpenLayerMap("Groundwater Map", "bgr_groundwater_whymap", "http://www.bgr.de/Service/groundwater/whymap/");
+//		addBaseLayerToOpenLayerMap("LandMask", "LandMask", "http://oos.soest.hawaii.edu/erddap/wms/etopo1_ice/request");
+//		addBaseLayerToOpenLayerMap("Coastlines", "Coastlines", "http://oos.soest.hawaii.edu/erddap/wms/etopo1_ice/request");
+////		addBaseLayer("test2", "NWW3_Global_Best:Tdir", "http://oos.soest.hawaii.edu/erddap/wms/NWW3_Global_Best/request");
+//		addBaseLayerToOpenLayerMap("GEBCO", "GEBCO_08_Grid", "http://www.gebco.net/data_and_products/web_map_service/mapserv/request");
+//		addBaseLayerToOpenLayerMap("test2", "", ""); // do not anything
 
 		//var extent = new OpenLayers.Bounds(-20037508.34,-20037508.34,20037508.34,20037508.34); //-2200000,-712631,3072800,3840000);
 		
@@ -680,7 +702,7 @@ public class OpenLayersMap {
 	 * @param layerName
 	 * @param url
 	 */
-	private void addBaseLayer(String title, String layerName, String url) {
+	private void addBaseLayerToOpenLayerMap(String title, String layerName, String url) {
 		if (url==null || url.equals("") || layerName==null || layerName.equals(""))
 			return;
 		LayerItem l = new LayerItem(true);
